@@ -29,6 +29,7 @@
 #include <kglobal.h>
 #include <khtml_part.h>
 #include <kiconloader.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kmimetype.h>
 #include <kprocess.h>
@@ -62,6 +63,7 @@ SearchBarPlugin::SearchBarPlugin(QObject *parent, const char *name,
 	m_searchCombo->setDuplicatesEnabled(false);
 	m_searchCombo->setMaxCount(5);
 	m_searchCombo->setFixedWidth(180);
+	m_searchCombo->setLineEdit(new KLineEdit(m_searchCombo));
 	m_searchCombo->lineEdit()->installEventFilter(this);
 
 	m_popupMenu = 0;
@@ -255,12 +257,15 @@ void SearchBarPlugin::startSearch(const QString &search)
 
 void SearchBarPlugin::setIcon()
 {
+	QString hinttext;
 	if(m_searchMode == FindInThisPage)
 	{
 		m_searchIcon = SmallIcon("find");
+		hinttext = i18n("Find in This Page");
 	}
 	else
 	{
+		QString providername;
 		KService::Ptr service;
 		KURIFilterData data;
 		QStringList list;
@@ -277,18 +282,22 @@ void SearchBarPlugin::setIcon()
 			QString iconPath = locate("cache", KMimeType::favIconForURL(data.uri()) + ".png");
 			if(iconPath.isEmpty())
 			{
-				m_searchIcon = SmallIcon("unknown");
+				m_searchIcon = SmallIcon("enhanced_browsing");
 			}
 			else
 			{
 				m_searchIcon = QPixmap(iconPath);
 			}
+			providername = service->name();
 		}
 		else
 		{
 			m_searchIcon = SmallIcon("google");
+			providername = "Google";
 		}
+		hinttext = i18n("%1 Search").arg(providername);;
 	}
+	static_cast<KLineEdit*>(m_searchCombo->lineEdit())->setClickMessage(hinttext);
 
         // Create a bit wider icon with arrow
 	QPixmap arrowmap = QPixmap(m_searchIcon.width()+5,m_searchIcon.height()+5);
@@ -297,7 +306,7 @@ void SearchBarPlugin::setIcon()
 	p.drawPixmap(0, 2, m_searchIcon);
 	QStyle::SFlags arrowFlags = QStyle::Style_Default;
 	m_searchCombo->style().drawPrimitive(QStyle::PE_ArrowDown, &p, QRect(arrowmap.width()-6, 
-	    arrowmap.height()-5, 6, 5), m_searchCombo->colorGroup(), arrowFlags, QStyleOption() );
+	    arrowmap.height()-6, 6, 5), m_searchCombo->colorGroup(), arrowFlags, QStyleOption() );
 	p.end();
 	m_searchIcon = arrowmap;
 
@@ -335,7 +344,7 @@ void SearchBarPlugin::showSelectionMenu()
 				QString iconPath = locate("cache", KMimeType::favIconForURL(data.uri()) + ".png");
 				if(iconPath.isEmpty())
 				{
-					icon = SmallIcon("unknown");
+					icon = SmallIcon("enhanced_browsing");
 				}
 				else
 				{
